blob2d
======

This module allows 2D simulations of drift-reduced blobs in a slab geometry with
curvature.

The model is gyro-bohm normalized (length scales normalized to `rho_s`, time
normalized to `Omega_i`)

Input test cases
----------------

- `delta_0.25`  - Blob with size `0.25 * delta_*`
- `delta_1`     - Blob with size `delta_*`
- `delta_10`    - Blob with size `10 * delta_*`
